==> die-engine_3.03.orig.tar.gz: die-engine-3.03/build_tools/README.md <==
Build tools
=======
Visual Studio Community 2013 with Update 5: https://my.visualstudio.com/Downloads?q=visual%20studio%202013&wt.mc_id=o~msft~vscom~older-downloads (Login with GitHub)

Visual Studio Community 2017 (version 15.9): https://my.visualstudio.com/Downloads?q=visual%20studio%202017&wt.mc_id=o~msft~vscom~older-downloads (Login with GitHub)

Visual Studio Community 2019 (version 16.7): https://my.visualstudio.com/downloads (Login with GitHub)

7-Zip: https://www.7-zip.org/

Inno Setup: https://jrsoftware.org/isdl.php

(Linux)Qt 5.6.3(x64): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-linux-x64-5.6.3.run

(Linux)Qt 5.9-5.15(x64): https://www.qt.io/download

(OSX)Qt 5.6.3(x64): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-mac-x64-clang-5.6.3.dmg

(OSX)Qt 5.9-5.15(x64): https://www.qt.io/download

(Windows)Qt 5.6.2 for VS2013(x86): https://download.qt.io/new_archive/qt/5.6/5.6.2/qt-opensource-windows-x86-msvc2013-5.6.2.exe

(Windows)Qt 5.6.2 for VS2013(x64): https://download.qt.io/new_archive/qt/5.6/5.6.2/qt-opensource-windows-x86-msvc2013_64-5.6.2.exe

(Windows)Qt 5.6.3 for VS2013(x86): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-windows-x86-msvc2013-5.6.3.exe

(Windows)Qt 5.6.3 for VS2013(x64): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-windows-x86-msvc2013_64-5.6.3.exe

(Windows)Qt 5.9-5.15(x86-x64): https://www.qt.io/download

UPX: https://github.com/upx/upx/releases

SQLite tools: https://www.sqlite.org/2018/sqlite-tools-win32-x86-3240000.zip

WDK 7.1.0 (for Windows XP drivers): https://www.microsoft.com/download/confirmation.aspx?id=11800

Install Qt 5.15.1 for Linux https://www.qt.io/download (Downloads for open source users)

- Desktop gcc 64-bit
- Qt Script

![alt text](https://github.com/horsicq/build_tools/blob/master/images/Linux_Qt5_15_1.png "Qt 5.15.1")

Install Qt 5.15.1 for OSX https://www.qt.io/download (Downloads for open source users)

- macOS
- Qt Script

![alt text](https://github.com/horsicq/build_tools/blob/master/images/OSX_Qt5_15_1.png "Qt 5.15.1")

Install Qt 5.15.1 for Windows https://www.qt.io/download (Downloads for open source users)

- MSVC 2019 32-bit
- MSVC 2019 64-bit
- Qt Script

![alt text](https://github.com/horsicq/build_tools/blob/master/images/Windows_Qt5_15_1.png "Qt 5.15.1")

==> die-engine_3.07.orig.tar.gz: die-engine-3.07/build_tools/README.md <==
Build tools
=======
Visual Studio Community 2013 with Update 5: https://my.visualstudio.com/Downloads?q=visual%20studio%202013&wt.mc_id=o~msft~vscom~older-downloads (Login with GitHub)

Visual Studio Community 2017 (version 15.9): https://my.visualstudio.com/Downloads?q=visual%20studio%202017&wt.mc_id=o~msft~vscom~older-downloads (Login with GitHub)

Visual Studio Community 2019 (version 16.7): https://my.visualstudio.com/downloads (Login with GitHub)

7-Zip: https://www.7-zip.org/

Inno Setup: https://jrsoftware.org/isdl.php

(Linux)Qt 5.6.3(x64): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-linux-x64-5.6.3.run

(Linux)Qt 5.15.2(x64): https://www.qt.io/download

(macOS)Qt 5.6.3(x64): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-mac-x64-clang-5.6.3.dmg

(macOS)Qt 5.15.2(x64): https://www.qt.io/download

(Windows)Qt 5.6.2 for VS2013(x86): https://download.qt.io/new_archive/qt/5.6/5.6.2/qt-opensource-windows-x86-msvc2013-5.6.2.exe

(Windows)Qt 5.6.2 for VS2013(x64): https://download.qt.io/new_archive/qt/5.6/5.6.2/qt-opensource-windows-x86-msvc2013_64-5.6.2.exe

(Windows)Qt 5.6.3 for VS2013(x86): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-windows-x86-msvc2013-5.6.3.exe

(Windows)Qt 5.6.3 for VS2013(x64): https://download.qt.io/new_archive/qt/5.6/5.6.3/qt-opensource-windows-x86-msvc2013_64-5.6.3.exe

(Windows)Qt 5.15.2(x86-x64): https://www.qt.io/download

UPX: https://github.com/upx/upx/releases

SQLite tools: https://www.sqlite.org/2018/sqlite-tools-win32-x86-3240000.zip

WDK 7.1.0 (for Windows XP drivers): https://www.microsoft.com/download/confirmation.aspx?id=11800

WDK 11 (for Windows 7-11 drivers): https://go.microsoft.com/fwlink/?linkid=2166289

Windows SDK: https://go.microsoft.com/fwlink/?linkid=2173743

Install Qt 5.15.2 for Linux https://www.qt.io/download (Downloads for open source users)

- Desktop gcc 64-bit
- Qt Script

![alt text](https://github.com/horsicq/build_tools/blob/master/images/Linux_Qt5_15_1.png "Qt 5.15.1")

Install Qt 5.15.2 for OSX https://www.qt.io/download (Downloads for open source users)

- macOS
- Qt Script

![alt text](https://github.com/horsicq/build_tools/blob/master/images/OSX_Qt5_15_1.png "Qt 5.15.1")

Install Qt 5.15.2 for Windows https://www.qt.io/download (Downloads for open source users)

- MSVC 2019 32-bit
- MSVC 2019 64-bit
- Qt Script

![alt text](https://github.com/horsicq/build_tools/blob/master/images/Windows_Qt5_15_1.png "Qt 5.15.1")
